get_make: get_make

Description Usage Value Author(s) Examples

Description

Obtain all the makes included in Autocosmos website for the current year

Usage

1

Value

A character string containing all the makes in the catalog.

Author(s)

Jean Arreola

Examples

1

jean9208/Autocosmos documentation built on May 18, 2019, 11:42 p.m.