Description Usage Value Author(s) Examples
Obtain all the makes included in Autocosmos website for the current year
1 | get_make()
|
A character string containing all the makes in the catalog.
Jean Arreola
1 | get_make()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.